SystemOrganization addCategory: #'Xpf-Client-Tests'!
SystemOrganization addCategory: #'Xpf-Client-Morphs'!
SystemOrganization addCategory: #'Xpf-Client-Helpers'!
SystemOrganization addCategory: #'Xpf-Client-AdminTool'!

PasteUpMorph subclass: #XpfProjectMorph
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Client-Morphs'!

!XpfProjectMorph class methodsFor: 'initialize-release' stamp: 'topa 3/3/2009 20:51'!
forProject: anXpfProject

	^ self new
		model: anXpfProject! !

!XpfProjectMorph methodsFor: 'accessing' stamp: 'cs 2/26/2009 18:57'!
addUserStoryMorph: anXpfUserStoryMorph

	^ self addMorph:
		"Places new UserStories in the top left corner with 5 indent"
		(anXpfUserStoryMorph topLeft: (self submorphCount * 5 asPoint))! !

!XpfProjectMorph methodsFor: 'initialization' stamp: 'topa 3/3/2009 20:18'!
buildUserStorySubmorphs

	self model userStories do: [ :userStory| 
		self addUserStoryMorph: (XpfUserStoryMorph forUserStory: userStory)]! !

!XpfProjectMorph methodsFor: 'initialization' stamp: 'cs 2/26/2009 18:55'!
initialize
	super initialize.
	self
		acquireBorderWidth: 5.! !

!XpfProjectMorph methodsFor: 'accessing' stamp: 'SR 2/23/2009 12:14'!
model: anObject

	self removeAllMorphsIn: self userStorySubmorphs. 
	model := anObject.
	self buildUserStorySubmorphs.
! !

!XpfProjectMorph methodsFor: 'accessing' stamp: 'SR 2/23/2009 10:51'!
userStorySubmorphs

	^ self allMorphs select: [:aMorph| aMorph isUserStoryMorph]! !

XpfTestCase subclass: #XpfAdminToolTest
	instanceVariableNames: 'tool factoryMock'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Client-Tests'!

!XpfAdminToolTest methodsFor: 'setup' stamp: 'cs 3/3/2009 15:40'!
setUp

	tool := XpfAdminTool new.
	factoryMock := XpfProxyObjectFactoryMock new.
	tool initializeWith: factoryMock.! !

!XpfAdminToolTest methodsFor: 'tests' stamp: 'mt 3/3/2009 17:21'!
testEditProjectTitle
	
	tool titleMorph setText: 'testEditProjectTitle'.
	tool saveTitleButton performAction.
	
	self
		should: tool projectList selection = 'testEditProjectTitle';
		should: tool model projects first title = 'testEditProjectTitle'.! !

!XpfAdminToolTest methodsFor: 'tests' stamp: 'cs 3/3/2009 15:35'!
testGetAllProjects
	
	self
		should: tool projectList getList size = 1;
		should: tool projectList getList first = factoryMock getAllProjects first title.! !

!XpfAdminToolTest methodsFor: 'tests' stamp: 'mt 3/3/2009 16:34'!
testSelectProject
	
	tool projectList selection: factoryMock projectTitle.
	self
		should: tool projectList selectionIndex = 1;
		should: tool titleMorph text = factoryMock projectTitle.! !

XpfTestCase subclass: #XpfClientTest
	instanceVariableNames: 'project userstory1 userstory2'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Client-Tests'!

!XpfClientTest methodsFor: 'running' stamp: 'mt 2/26/2009 16:59'!
setUp
	super setUp.
	project := XpfProject new title: 'Test Project'.
	userstory1 := XpfUserStory new title: 'Test User Story with long title.'; explanation: 'This is the explanantion of a user story.'.
	userstory2 := XpfUserStory new title: 'Test User Story'.
	project
		addUserStory: userstory1;
		addUserStory: userstory2.! !

!XpfClientTest methodsFor: 'running' stamp: 'cs 2/23/2009 15:50'!
tearDown
	project
		removeUserStory: userstory1;
		removeUserStory: userstory1! !

!XpfClientTest methodsFor: 'tests' stamp: 'topa 3/3/2009 20:16'!
testAddUSMorphsToProjectMorph

	| sut usMorphCount |
	sut := XpfProjectMorph new.
	usMorphCount := sut userStorySubmorphs size.
	
	sut addUserStoryMorph: (XpfUserStoryMorph forUserStory: userstory1).
	self should: sut userStorySubmorphs size = (usMorphCount + 1).! !

!XpfClientTest methodsFor: 'tests' stamp: 'topa 3/3/2009 20:17'!
testProjectTitleDisplay

	| sut |
	sut := XpfClient forProject: project.
	
 	self should: sut label = project printString.! !

!XpfClientTest methodsFor: 'tests' stamp: 'topa 3/3/2009 20:17'!
testUserStoryDetailWindow

	| sut |
	sut := XpfUserStoryDetailWindow forUserStory: userstory1.

	self
		should: sut titleText getText = userstory1 title
		description: 'The text entry should contain the title of the user story.'.
		
	self
		should: sut explanationText getText = userstory1 explanation
		description: 'The explanation is not correct'.! !

!XpfClientTest methodsFor: 'tests' stamp: 'topa 3/3/2009 20:17'!
testUserStoryDetailWindowOk

	| sut newTitle newExp |
	sut := XpfUserStoryDetailWindow forUserStory: userstory1.
	
	newTitle := 'Changed Text.'.
	newExp := 'Changed Explanation.'.

	sut titleText textMorph contents: newTitle.
	sut explanationText textMorph contents: newExp.
	
	self
		shouldnt: userstory1 title = newTitle;
		shouldnt: userstory1 explanation = newExp.
	sut ok.
	
	self
		should: userstory1 title = newTitle;
		should: userstory1 explanation = newExp.! !

!XpfClientTest methodsFor: 'tests' stamp: 'topa 3/3/2009 20:17'!
testUserStorySubmorphs

	| sut |
	sut := XpfProjectMorph forProject: project.
	
	
	self 
		should: sut userStorySubmorphs size = project userStories size.
		
	sut userStorySubmorphs do: [ :usMorph| 
		self should: (project userStories includes: usMorph model)].! !

!XpfClientTest methodsFor: 'tests' stamp: 'topa 3/3/2009 20:17'!
testUserStoryTextContent

	| sut titleMorph |
	sut := XpfUserStoryMorph forUserStory: userstory2.
	self should: sut submorphCount > 0.
	
	titleMorph := sut submorphs detect: [:submorph |
			submorph isTextMorph and: [submorph text asString = userstory2 printString]].
	self
		shouldnt: titleMorph isNil;
		should: (titleMorph wrapString startsWith: '<yes>');
	 	should: titleMorph width <= 100.! !

Object subclass: #XpfAdminToolModel
	instanceVariableNames: 'factory projects currentProjectIndex'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Client-AdminTool'!

!XpfAdminToolModel class methodsFor: 'as yet unclassified' stamp: 'topa 3/3/2009 20:19'!
newWithFactory: aFactory

	^ self new factory: aFactory! !

!XpfAdminToolModel methodsFor: 'accessing' stamp: 'mt 3/3/2009 17:04'!
allProjectTitles

	^ self projects collect: [:project | project title]! !

!XpfAdminToolModel methodsFor: 'accessing' stamp: 'mt 3/3/2009 16:22'!
currentProjectIndex
	^ currentProjectIndex! !

!XpfAdminToolModel methodsFor: 'accessing' stamp: 'mt 3/3/2009 16:57'!
currentProjectIndex: anObject

	currentProjectIndex := anObject.
	self
		changed: #currentProjectIndex;
		changed: #currentProjectTitle.! !

!XpfAdminToolModel methodsFor: 'accessing' stamp: 'mt 3/3/2009 17:04'!
currentProjectTitle

	^ self allProjectTitles at: self currentProjectIndex! !

!XpfAdminToolModel methodsFor: 'accessing' stamp: 'mt 3/3/2009 17:04'!
currentProjectTitle: aString

	(self projects at: self currentProjectIndex) title: aString.
	self
		changed: #currentProjectTitle;
		changed: #allProjectTitles.! !

!XpfAdminToolModel methodsFor: 'accessing' stamp: 'mt 3/2/2009 18:08'!
factory
	^ factory! !

!XpfAdminToolModel methodsFor: 'accessing' stamp: 'mt 3/2/2009 18:08'!
factory: anObject
	factory := anObject! !

!XpfAdminToolModel methodsFor: 'accessing' stamp: 'mt 3/3/2009 16:27'!
initialize

	super initialize.
	self currentProjectIndex: 1.! !

!XpfAdminToolModel methodsFor: 'accessing' stamp: 'mt 3/3/2009 17:01'!
projects
	
	projects ifNil: [projects := factory getAllProjects].
	^ projects! !

Object subclass: #XpfProxyObjectFactoryMock
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Client-Tests'!

!XpfProxyObjectFactoryMock methodsFor: 'add-remove' stamp: 'mt 3/2/2009 17:48'!
addProject: aProject

	^ aProject! !

!XpfProxyObjectFactoryMock methodsFor: 'accessing' stamp: 'cs 3/3/2009 15:40'!
getAllProjects

	^ {XpfProject new title: self projectTitle}! !

!XpfProxyObjectFactoryMock methodsFor: 'accessing' stamp: 'cs 3/3/2009 15:39'!
projectTitle

	^ 'Testproject'! !

PluggableDialogWindow subclass: #XpfAdminTool
	instanceVariableNames: 'projectList titleMorph saveTitleButton'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Client-AdminTool'!

!XpfAdminTool class methodsFor: 'user interface' stamp: 'topa 3/3/2009 16:59'!
open

	| instance text factory |
	instance := self new.
	text := UITheme current 
				textEntryIn: instance
				text: 'Enter server connection'
				title: 'Connection'
				entryText: 'http://localhost:8082/'.
	text ifNil: [^ text].
	factory := XpfProxyObjectFactory fromString: text.
	^ (instance initializeWith: factory) openInWorld! !

!XpfAdminTool methodsFor: 'initialization' stamp: 'mt 3/3/2009 17:18'!
createProjectListFor: aModel

	self projectList: (UITheme current
		newListIn: self
		for: aModel
		list: #allProjectTitles
		selected: #currentProjectIndex
		changeSelected: #currentProjectIndex:
		getEnabled: nil
		help: 'Shows all projects.').
	^ self projectList! !

!XpfAdminTool methodsFor: 'initialization' stamp: 'mt 3/3/2009 17:16'!
createSaveTitleButtonFor: myModel

	self saveTitleButton: (UITheme current
		newButtonIn: self 
		for: self titleMorph 
		getState: nil 
		action: #accept
		arguments: nil 
		getEnabled: nil 
		label: 'Save' 
		help: 'Save changed project title').
	^ self saveTitleButton! !

!XpfAdminTool methodsFor: 'initialization' stamp: 'cs 3/3/2009 15:42'!
createTitleLabel

	^ UITheme current
		newLabelIn: self
		label: 'Title:'.! !

!XpfAdminTool methodsFor: 'initialization' stamp: 'mt 3/3/2009 17:17'!
createTitleTextEntryFor: myModel

	self titleMorph: ((UITheme current
		newTextEntryIn: self
		for: myModel
		get: #currentProjectTitle
		set: #currentProjectTitle:
		class: String
		getEnabled: nil
		help: 'Enter a short descriptive title for this project.') maxLength: 100).
	^ self titleMorph! !

!XpfAdminTool methodsFor: 'initialization' stamp: 'mt 3/3/2009 17:22'!
initializeUserInterface: myModel

	| col row |
	col := UITheme current newColumnIn: self for: {
		self createTitleLabel.
		self createTitleTextEntryFor: myModel.
		self createSaveTitleButtonFor: myModel}.
	row := UITheme current newRowIn: self for: {
		self createProjectListFor: myModel.
		col}.
		
	row vResizing: #spaceFill.
	
	^ row! !

!XpfAdminTool methodsFor: 'initialization' stamp: 'topa 3/3/2009 20:19'!
initializeWith: aFactory

	| myModel |
	myModel := XpfAdminToolModel newWithFactory: aFactory.
	self
		contentMorph: (self initializeUserInterface: myModel);
		model: myModel;
		addGrips;
		title: 'Project Management'.! !

!XpfAdminTool methodsFor: 'accessing' stamp: 'mt 3/2/2009 17:57'!
projectList
	^ projectList! !

!XpfAdminTool methodsFor: 'accessing' stamp: 'mt 3/2/2009 17:57'!
projectList: anObject
	projectList := anObject! !

!XpfAdminTool methodsFor: 'accessing' stamp: 'mt 3/3/2009 17:16'!
saveTitleButton
	^ saveTitleButton! !

!XpfAdminTool methodsFor: 'accessing' stamp: 'mt 3/3/2009 17:16'!
saveTitleButton: anObject
	saveTitleButton := anObject! !

!XpfAdminTool methodsFor: 'accessing' stamp: 'cs 3/3/2009 15:47'!
titleMorph
	^ titleMorph! !

!XpfAdminTool methodsFor: 'accessing' stamp: 'cs 3/3/2009 15:47'!
titleMorph: anObject
	titleMorph := anObject! !

PluggableDialogWindow subclass: #XpfUserStoryDetailWindow
	instanceVariableNames: 'explanationText titleText'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Client-Morphs'!

!XpfUserStoryDetailWindow class methodsFor: 'instance creation' stamp: 'topa 3/3/2009 20:51'!
forUserStory: aUserStory

	^ self new initializeWith: aUserStory! !

!XpfUserStoryDetailWindow methodsFor: 'actions' stamp: 'cs 2/26/2009 19:09'!
close
	
	super close.
	self changed: #detailsClosed.! !

!XpfUserStoryDetailWindow methodsFor: 'initialization' stamp: 'cs 2/26/2009 18:33'!
createExplanationTextFor: aUserStory

	explanationText := UITheme current
		newTextEditorIn: self
		for: aUserStory
		getText: #explanation
		setText: #explanation:
		getEnabled: nil.
	^ explanationText
		alwaysAccept: true;
		yourself! !

!XpfUserStoryDetailWindow methodsFor: 'initialization' stamp: 'mt 2/26/2009 17:04'!
createLabel

	^ UITheme current
		newLabelIn: self
		label: 'Title:'.! !

!XpfUserStoryDetailWindow methodsFor: 'initialization' stamp: 'mt 2/26/2009 17:10'!
createTitleTextFor: aUserStory

	titleText := (UITheme current
		newTextEntryIn: self
		for: aUserStory
		get: #title
		set: #title:
		class: String
		getEnabled: nil
		help: 'Enter a short descriptive title for this user story.') maxLength: 100.
	^ titleText! !

!XpfUserStoryDetailWindow methodsFor: 'accessing' stamp: 'mt 2/26/2009 17:10'!
explanationText
	^ explanationText! !

!XpfUserStoryDetailWindow methodsFor: 'accessing' stamp: 'mt 2/26/2009 17:10'!
explanationText: anObject
	explanationText := anObject! !

!XpfUserStoryDetailWindow methodsFor: 'initialization' stamp: 'mt 2/26/2009 17:39'!
initializeWith: aUserStory

	| col row |	
	row := UITheme current newRowIn: self for: {
		self createLabel.
		self createTitleTextFor: aUserStory}.
		
	col := UITheme current newColumnIn: self for: {
		row.
		self createExplanationTextFor: aUserStory}.
		
	self
		contentMorph: col;
		model: aUserStory;
		addGrips;
		title: aUserStory title.! !

!XpfUserStoryDetailWindow methodsFor: 'actions' stamp: 'cs 2/26/2009 19:10'!
ok

	self titleText accept.
	self explanationText accept.	
	self changed: #detailsClosed.
	super ok.! !

!XpfUserStoryDetailWindow methodsFor: 'accessing' stamp: 'mt 2/26/2009 17:10'!
titleText
	^ titleText! !

!XpfUserStoryDetailWindow methodsFor: 'accessing' stamp: 'mt 2/26/2009 17:10'!
titleText: anObject
	titleText := anObject! !

!Morph methodsFor: '*xpf-client' stamp: 'SR 2/23/2009 10:49'!
isUserStoryMorph
	^ false! !

Morph subclass: #XpfUserStoryMorph
	instanceVariableNames: 'model titleMorph enabled'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Client-Morphs'!

!XpfUserStoryMorph class methodsFor: 'defaults' stamp: 'cs 2/26/2009 18:45'!
defaultBorderColor
	^ Color darkGray! !

!XpfUserStoryMorph class methodsFor: 'defaults' stamp: 'cs 2/26/2009 18:49'!
defaultColor
	^ Color paleTan! !

!XpfUserStoryMorph class methodsFor: 'defaults' stamp: 'cs 2/26/2009 19:10'!
defaultDisabledBorderColor
	^ Color gray! !

!XpfUserStoryMorph class methodsFor: 'defaults' stamp: 'cs 2/26/2009 19:11'!
defaultDisabledColor
	^ Color veryVeryLightGray ! !

!XpfUserStoryMorph class methodsFor: 'defaults' stamp: 'cs 2/26/2009 19:13'!
defaultDisabledTextColor
	^ Color darkGray! !

!XpfUserStoryMorph class methodsFor: 'defaults' stamp: 'cs 2/23/2009 15:08'!
defaultExtent
	^ 100@60 ! !

!XpfUserStoryMorph class methodsFor: 'defaults' stamp: 'cs 2/26/2009 18:59'!
defaultTextColor
	^ Color black! !

!XpfUserStoryMorph class methodsFor: 'initialize-release' stamp: 'topa 3/3/2009 20:52'!
forUserStory: anXpfUserStory

	^ self new
		model: anXpfUserStory! !

!XpfUserStoryMorph methodsFor: 'event handling' stamp: 'topa 3/3/2009 20:18'!
doubleClick: evt

	self enabled: false.
	(XpfUserStoryDetailWindow forUserStory: self model)
		addDependent: self;
		openInHand.! !

!XpfUserStoryMorph methodsFor: 'event handling' stamp: 'cs 2/26/2009 18:24'!
doubleClickTimeout: evt

	evt hand attachMorph: self.! !

!XpfUserStoryMorph methodsFor: 'accessing' stamp: 'mt 2/26/2009 18:07'!
enabled

	^ enabled! !

!XpfUserStoryMorph methodsFor: 'accessing' stamp: 'cs 2/26/2009 19:11'!
enabled: aBoolean

	enabled := aBoolean.
	self color:
		(enabled
			ifTrue: [self class defaultColor]
			ifFalse: [self class defaultDisabledColor]).
	self titleMorph color:
		(enabled
			ifTrue: [self class defaultTextColor]
			ifFalse: [self class defaultDisabledTextColor]).
	self borderColor:
		(enabled
			ifTrue: [self class defaultBorderColor]
			ifFalse: [self class defaultDisabledBorderColor]).! !

!XpfUserStoryMorph methodsFor: 'event handling' stamp: 'cs 2/26/2009 18:24'!
handlesMouseDown: evt

	self enabled ifTrue:
		[evt hand waitForClicksOrDrag: self event: evt].
	^ true! !

!XpfUserStoryMorph methodsFor: 'initialization' stamp: 'cs 2/26/2009 19:12'!
initialize

	super initialize.
	self
		extent: self class defaultExtent;
		titleMorph: TextMorph new lock;
		borderWidth: 2;
		enabled: true.! !

!XpfUserStoryMorph methodsFor: 'testing' stamp: 'SR 2/23/2009 10:49'!
isUserStoryMorph
	^ true! !

!XpfUserStoryMorph methodsFor: 'accessing' stamp: 'SR 2/23/2009 10:56'!
model
	^ model! !

!XpfUserStoryMorph methodsFor: 'accessing' stamp: 'cs 2/26/2009 19:07'!
model: anObject
	model := anObject.
	self update: #newModel.! !

!XpfUserStoryMorph methodsFor: 'accessing' stamp: 'cs 2/26/2009 11:26'!
titleMorph
	^ titleMorph! !

!XpfUserStoryMorph methodsFor: 'accessing' stamp: 'cs 2/26/2009 11:52'!
titleMorph: anObject
	titleMorph ifNotNil: [self removeMorph: titleMorph].
	titleMorph := anObject.
	self addMorph: titleMorph.
	titleMorph topLeft: 4@2! !

!XpfUserStoryMorph methodsFor: 'updating' stamp: 'topa 3/3/2009 16:41'!
update: aSymbol

	aSymbol = #detailsClosed ifTrue: [self enabled: true].
	self titleMorph
		contents: (self model title truncateWithElipsisTo: 24);
		wrapFlag: true;
		extent: 100@60.! !

RestProxyObjectFactory subclass: #XpfProxyObjectFactory
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Client-Helpers'!

!XpfProxyObjectFactory methodsFor: 'add-remove' stamp: 'cs 2/27/2009 15:21'!
addProject: aProject 

	^ self addObject: 'projects/' with: aProject! !

!XpfProxyObjectFactory methodsFor: 'accessing' stamp: 'topa 3/3/2009 17:46'!
getAllProjects

	^ self getCollection: 'projects/'! !

PluggableSystemWindow subclass: #XpfClient
	instanceVariableNames: 'projectMorph'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Client-Morphs'!

!XpfClient class methodsFor: 'as yet unclassified' stamp: 'topa 3/3/2009 20:16'!
forProject: anXpfProject

	^ self new
		model: anXpfProject;
		getLabelSelector: #title.! !

!XpfClient methodsFor: 'initialization' stamp: 'topa 3/3/2009 20:14'!
initialize

	super initialize.	
	self 
		projectMorph: XpfProjectMorph new;
		addMorph: self projectMorph 
		fullFrame: (LayoutFrame fractions: (0@0 corner: 1@1) offsets: (0@0 corner: 0@0)).! !

!XpfClient methodsFor: 'accessing' stamp: 'topa 3/3/2009 20:14'!
model: anXpfProject

	super model: anXpfProject.
	self projectMorph model: anXpfProject.! !

!XpfClient methodsFor: 'accessing' stamp: 'topa 3/3/2009 20:13'!
projectMorph

	^ projectMorph! !

!XpfClient methodsFor: 'accessing' stamp: 'topa 3/3/2009 20:13'!
projectMorph: anObject

	projectMorph := anObject! !

XpfRestTest subclass: #XpfModelToProxyTest
	instanceVariableNames: 'proxy'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Client-Tests'!

!XpfModelToProxyTest methodsFor: 'as yet unclassified' stamp: 'topa 3/3/2009 16:59'!
setUp
	
	|factory|
	super setUp.
	factory := XpfProxyObjectFactory fromString: self class url.
	proxy := factory getAllProjects first.! !

!XpfModelToProxyTest methodsFor: 'as yet unclassified' stamp: 'topa 3/3/2009 16:48'!
testTitle

	self should: proxy title = testProject title.
	
	proxy userStories with: testProject userStories do: 
		[:proxyUS :realUS | 
			self should: proxyUS title = realUS title].! !
